# GachaPy

A Python engine for gacha games  

##### Install through pip
```pip install gachapy```
[gachapy PyPi page](https://pypi.org/project/gachapy/)

##### Documentation
[gachapy documentation](https://gachapy.readthedocs.io/)